<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * RestaurantGuide Component Categories Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideControllerCategories extends restaurantguideController
{
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add'  ,		 	'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'accesspublic', 	'access' );
		$this->registerTask( 'accessregistered','access' );
		$this->registerTask( 'accessspecial', 	'access' );
	}

	/**
	 * Logic to save a category
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		global $rgconf;
		
		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		$task		= JRequest::getVar('task');

		//Sanitize
		$post = JRequest::get( 'post' );
		$post['description'] = JRequest::getVar( 'description', '', 'post', 'string', JREQUEST_ALLOWRAW );

		$delete_image = JRequest::getCmd('delete_image', false, 'post');
		
		$model = $this->getModel('category');
		$data = $model->getFile($post['id']);

		$dir = RESTAURANTGUIDE_IMAGES_CATEGORY_ALBUM_URL;
		$resize_dir = RESTAURANTGUIDE_IMAGES_CATEGORY_RESIZE_URL;
		$thumb_dir = RESTAURANTGUIDE_IMAGES_CATEGORY_THUMB_URL;
			
		if ($delete_image) {
			$post['image'] = null;
			$post['imagewidth'] = '';
			$post['imageheight'] = '';

			if (JFile::exists($dir.$data->image)) {
				JFile::delete($dir.$data->image);
			}
			
			if (JFile::exists($resize_dir.$data->image)) {
				JFile::delete($resize_dir.$data->image);
			}

			if (JFile::exists($thumb_dir.$data->image)) {
				JFile::delete($thumb_dir.$data->image);
			}
		}
		
		if (isset($_FILES['file_upload'])){
			
			$handle = new Upload($_FILES['file_upload']);

			if ($handle->uploaded) {

				if (!file_exists($dir) && JPath::isOwner($dir) && !JPath::setPermissions($dir, '0755')) {
					JError::raiseNotice('SOME_ERROR_CODE', 'COULD NOT MAKE CATEGORY DIRECTORY WRITABLE');
				}

				if (!file_exists($resize_dir)) {
					mkdir($resize_dir, 0777);
				}

				if (!file_exists($thumb_dir)) {
					mkdir($thumb_dir, 0777);
				}
				
				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);

				$post['image'] = $handle->file_dst_name;	
				
				$handle->image_resize = true;
				$handle->image_ratio_y = true;
				if ($rgconf->category_width)
					$handle->image_x = $rgconf->category_width;
				else
					$handle->image_x = 180;
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;

				$handle->Process($resize_dir);
				
				$imagewidth = $handle->image_dst_x;
				$imageheight = $handle->image_dst_y;
				$post['imagewidth'] = $imagewidth;
				$post['imageheight'] = $imageheight;
				
				// thumbnail image
				$handle->image_resize = true;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					if ($rgconf->thumb_size)
						$handle->image_x = $rgconf->thumb_size;
					else 
						$handle->image_x = 74;
				} else {
					$handle->image_ratio_x = true;
					if ($rgconf->thumb_size)
						$handle->image_y = $rgconf->thumb_size;
					else
						$handle->image_y = 74;
				}
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;
				
				$handle->Process($thumb_dir);
				
				$handle->Clean();
			}
		}
			
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=category&cid[]='.(int) $model->get('id');
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=categories';
					break;
			}
			$msg = JText::_( 'CATEGORY DATE SUCCESSFULLY SAVED' );
			
			//Take care of access levels and state
			$categoriesmodel = & $this->getModel('categories');
			$categoriesmodel->access($model->get('id'), $model->get('access'));
			
			$pubid = array();
			$pubid[] = $model->get('id');
			if($model->get('published') == 1) {
				$categoriesmodel->publish($pubid, 1);
			} else {
				$categoriesmodel->publish($pubid, 0);
			}
			
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();

		} else {

			$msg 	= JText::_( 'ERROR SAVING CATEGORY' );
			$link 	= 'index.php?option=com_restaurantguide&view=category';
		}

		$model->checkin();

		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to publish categories
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function publish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM PUBLISH' ) );
		} else {

			$model = $this->getModel('categories');

			if(!$model->publish($cid, 1)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'CATEGORY PUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories', $msg );
	}

	/**
	 * Logic to unpublish categories
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function unpublish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM UNPUBLISH' ) );
		} else {

			$model = $this->getModel('categories');

			if(!$model->publish($cid, 0)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'CATEGORY UNPUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories', $msg );
	}

	/**
	 * Logic to orderup a category
	 *
	 * @access public
	 * @return void;
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('categories');
		$model->move(-1);
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories');
	}

	/**
	 * Logic to orderdown a category
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('categories');
		$model->move(1);
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories');
	}

	/**
	 * Logic to mass ordering categories
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('categories');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseWarning(500, $model->getError());
		}
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		$msg = 'NEW ORDERING SAVED';
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories', $msg );
	}

	/**
	 * Logic to delete categories
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM DELETE' ) );
		} else {

			$model = $this->getModel('categories');

			$msg = $model->delete($cid);

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$category = & JTable::getInstance('rg_categories', '');
		$category->bind(JRequest::get('post'));
		$category->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories' );
	}

	/**
	 * Logic to set the category access level
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function access( )
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$id			= (int)$cid[0];
		$task		= JRequest::getVar( 'task' );

		if ($task == 'accesspublic') {
			$access = 0;
		} elseif ($task == 'accessregistered') {
			$access = 1;
		} else {
			$access = 2;
		}

		$model = $this->getModel('categories');
		
		if(!$model->access( $id, $access )) {
			JError::raiseError(500, $model->getError());
		} else {
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect('index.php?option=com_restaurantguide&view=categories' );
	}

	/**
	 * Logic to create the view for the edit categoryscreen
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{	
		// Check for request forgeries
		//JRequest::checkToken() or jexit( 'Invalid Token' );
		
		JRequest::setVar( 'view', 'category' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('category');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=categories', JText::_( 'EDITED BY ANOTHER ADMIN' ) );
		}

		$model->checkout( $user->get('id') );
		
		parent::display();
	}
}