<?php
/**
 * @version 1.0 $Id: cuisines.php 958 
 * @package Joomla
 * @subpackage Restaurant Guide
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENSE.php
 * Restaurant Guide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * Restaurant Guide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Restaurant Guide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Restaurant Guide Component Cuisines Controller
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since 0.9
 */
class restaurantguideControllerCuisines extends restaurantguideController
{
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add',		 	'edit' );
		$this->registerTask( 'apply', 		'save' );
		$this->registerTask( 'saveandnew', 	'save' );
		$this->registerTask( 'unpublish', 	'publish');	
	}

	/**
	 * display the edit form
	 * @return void
	 */

	function edit()
	{
		JRequest::setVar( 'view', 		'cuisine' );
		JRequest::setVar( 'layout', 	'default'  );
		JRequest::setVar( 'hidemainmenu', 1);

		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */

	function save()
	{
		JRequest::checkToken() or jexit( 'Invalid Token' );
			
		$post	= JRequest::get('post');

		$model	=& $this->getModel('cuisine');

		if ($model->store($post)) {
			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=cuisine&cid[]='.(int) $model->get('id');
					break;

				case 'saveandnew' :
					$link = 'index.php?option=com_restaurantguide&view=cuisine';
					break;
					
				default :
					$link = 'index.php?option=com_restaurantguide&view=cuisines';
					break;
			}
			$msg = JText::_( 'DATA SAVED' );
		} else {
			$link 	= 'index.php?option=com_restaurantguide&view=cuisines';
			$msg = JText::_( 'ERROR SAVING DATA' );
		}

		$this->setRedirect($link, $msg);
	}

	function publish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM PUBLISH' ) );
		} else {
			$model = $this->getModel('cuisine');

			if(!$model->publish($cid, 1)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'CUISINE PUBLISHED');
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=cuisines', $msg );
	}
	
	function unpublish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM UNPUBLISH' ) );
		} else {
			$model = $this->getModel('cuisine');

			if(!$model->publish($cid, 0)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'CUISINE UNPUBLISHED');
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=cuisines', $msg );
	}
	/**
	 * remove record(s)
	 * @return void
	 */

	function remove()
	{
		$model = $this->getModel('cuisine');

		if(!$model->delete()) {
			$msg = JText::_( 'ERROR: ONE OR MORE CUISINES NOT DELETE' );
		} else {
			$msg = JText::_( 'CUISINES DELETED' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=cuisines', $msg );
	}

	/**
	 * cancel editing a record
	 * @return void
	 */

	function cancel()
	{
		$msg = JText::_( 'OPERATION CANCELLED' );

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=cuisines', $msg );
	}
}

?>

