<?php
/**
 * @version 1.0 $Id: facilities.php
 * @package Joomla
 * @subpackage Restaurant Guide
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENSE.php
 * Restaurant Guide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * Restaurant Guide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Restaurant Guide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Restaurant Guide Component Facilities Controller
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since 0.9
 */
class restaurantguideControllerFacilities extends restaurantguideController
{
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add',		 	'edit' );
		$this->registerTask( 'apply', 		'save' );
		$this->registerTask( 'saveandnew', 	'save' );
		$this->registerTask( 'unpublish', 	'publish');	
	}

	/**
	 * display the edit form
	 * @return void
	 */

	function edit()
	{
		JRequest::setVar( 'view', 		'facility' );
		JRequest::setVar( 'layout', 	'default'  );
		JRequest::setVar( 'hidemainmenu', 1);

		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */

	function save()
	{
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		$post	= JRequest::get('post');
		$file	= JRequest::getVar( 'file_upload', '', 'files', 'array' );

		$model	=& $this->getModel('facility');

		if (isset($_FILES['file_upload'])){
			$handle = new Upload($_FILES['file_upload']);
			
			if ($handle->uploaded) {
				$dir =  RESTAURANTGUIDE_IMAGES_PICTOGRAM.DS;

				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);
				$post['pictogram'] = $handle->file_dst_name;	
				$handle->Clean();
			}
		}
		
		if ($model->store($post)) {
			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=facility&cid[]='.(int) $model->get('id');
					break;

				case 'saveandnew' :
					$link = 'index.php?option=com_restaurantguide&view=facility';
					break;
					
				default :
					$link = 'index.php?option=com_restaurantguide&view=facilities';
					break;
			}
			$msg = JText::_( 'Data Saved!' );
		} else {
			$link 	= 'index.php?option=com_restaurantguide&view=facilities';
			$msg = JText::_( 'Error Saving Data' );
		}

		$this->setRedirect($link, $msg);
	}

	function publish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM PUBLISH' ) );
		} else {
			$model = $this->getModel('facility');

			if(!$model->publish($cid, 1)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'FACILITY PUBLISHED');
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=facilities', $msg );
	}
	
	function unpublish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM UNPUBLISH' ) );
		} else {
			$model = $this->getModel('facility');

			if(!$model->publish($cid, 0)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'FACILITY UNPUBLISHED');
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=facilities', $msg );
	}
	/**
	 * remove record(s)
	 * @return void
	 */

	function remove()
	{
		$model = $this->getModel('facility');

		if(!$model->delete()) {
			$msg = JText::_( 'Error: One or More Facilities Could not be Deleted' );
		} else {
			$msg = JText::_( 'Facilities Deleted' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=facilities', $msg );
	}

	/**
	 * cancel editing a record
	 * @return void
	 */

	function cancel()
	{
		$msg = JText::_( 'Operation Cancelled' );

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=facilities', $msg );
	}
}

?>

