<?php
/**
 * @version 1.0 $Id: country.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component country Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelCountry extends JModel
{
	/**
	 * Type data
	 *
	 * @var object
	 */
	var $_country = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int type identifier
	 */
	function setId($id)
	{
		// Set type id and wipe data
		$this->_id	    = $id;
		$this->_country	= null;
	}
	
	/**
	 * Overridden get method to get properties from the type
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadCountry()) {
			if(isset($this->_country->$property)) {
				return $this->_country->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get type data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getCountry()
	{
		if ($this->_loadCountry())
		{
		}
		else  $this->_initCountry();
		
		return $this->_country;
	}


	/**
	 * Method to load country data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadCountry()
	{
		// Lets load the type if it doesn't already exist
		if (empty($this->_country))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_countries'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_country = $this->_db->loadObject();

			return (boolean) $this->_country;
		}
		return true;
	}

	/**
	 * Method to initialise the country data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initCountry()
	{
		// Lets load the country if it doesn't already exist
		if (empty($this->_country))
		{
			$country = new stdClass();
			$country->id					= 0;
			$country->name					= null;
			$country->alias					= null;
			$country->code_1				= null;
			$country->code_2				= null;
			$country->continent				= 0;
			$country->published				= 1;
			$country->image					= null;
			$country->image_size			= 0;
			$country->imagewidth			= 0;
			$country->imageheight			= 0;
			$country->description			= null;
			$country->meta_title			= null;
			$country->meta_description		= null;
			$country->meta_keywords			= null;
			$country->lat					= 0;
			$country->lon					= 0;
			$country->zoom					= 6;
			$country->maptype				= 'map';
			$country->mapheight				= 400;
			$this->_country					= $country;
			return (boolean) $this->_country;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
/*	function checkin()
	{
		if ($this->_id)
		{
			$country = & JTable::getInstance('hg_countries', '');
			return $country->checkout($uid, $this->_id);
		}
		return false;
	}
*/
	/**
	 * Method to checkout/lock the type
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
/*	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$country = & JTable::getInstance('hg_countries', '');
			return $country->checkout($uid, $this->_id);
		}
		return false;
	}
*/
	/**
	 * Tests if the type is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
/*	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadCountry())
		{
			if ($uid) {
				return ($this->_country->checked_out && $this->_country->checked_out != $uid);
			} else {
				return $this->_country->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}
*/
	/**
	 * Method to store the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$country  =& $this->getTable('rg_countries', '');

		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');
		
		// bind it to the table
		if (!$country->bind($data)) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$country->check()) {
			$this->setError($country->getError() );
			return false;
		}

		// Store it in the db
		if (!$country->store()) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_country	=& $country;

		//store tag relation
		$query = 'DELETE FROM #__rg_tags_item_relations WHERE country = '.$country->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__rg_tags_item_relations (`tid`, `country`) VALUES(' . $tag . ',' . $country->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		return true;
	}
	
	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	/**
	 * Method to fetch used tags when performing an edit action
	 * 
	 * @param int id
	 * @return array
	 * @since 1.0
	 */
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE country = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function addCountry($name, $country){
		
		$obj = new stdClass();
		$obj->name		= $name;
		$obj->country	= $country;
		$obj->published	= 1;
		
		$this->store($obj);
		
		return true;
	}
}
?>