<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Category Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelEvent extends JModel
{
	/**
	 * Category data
	 *
	 * @var object
	 */
	var $_event = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int category identifier
	 */
	function setId($id)
	{
		// Set category id and wipe data
		$this->_id	    = $id;
		$this->_event	= null;
	}
	
	/**
	 * Overridden get method to get properties from the category
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadEvent()) {
			if(isset($this->_event->$property)) {
				return $this->_event->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get category data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getEvent()
	{
		if ($this->_loadEvent())
		{

		}
		else  $this->_initEvent();

		return $this->_event;
	}

	/**
	 * Method to load category data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadEvent()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_event))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_events'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_event = $this->_db->loadObject();

			return (boolean) $this->_event;
		}
		return true;
	}

	/**
	 * Method to initialise the category data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initEvent()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_event))
		{
			$event = new stdClass();
			$event->id					= 0;
			$event->parent_id			= 0;
			$event->catid				= 0;
			$event->title				= null;
			$event->alias				= null;
			$event->resto				= 0;
			$event->statename			= 0;
			$event->country				= 0;
			$event->city				= 0;
			$event->description			= null;
			$event->meta_title			= null;
			$event->meta_keywords		= null;
			$event->meta_description	= null;
			$event->published			= 1;
			$event->hits				= 0;
			$event->image				= null;
			$event->image_size			= 0;
			$event->imagewidth			= 0;
			$event->imageheight			= 0;
			$event->startdates			= null;
			$event->enddates			= null;
			$event->tabtitle			= null;
			$event->lat					= 0;
			$event->lon					= 0;
			$event->zoom				= 6;
			$event->maptype				= 'map';
			$event->access				= 0;
			$this->_event				= $event;
			return (boolean) $this->_event;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the category
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$event = & JTable::getInstance('rg_events', '');
			return $event->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the category
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the category with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$event = & JTable::getInstance('rg_events', '');
			if(!$event->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}

	/**
	 * Tests if the category is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadEvent())
		{
			if ($uid) {
				return ($this->_event->checked_out && $this->_event->checked_out != $uid);
			} else {
				return $this->_event->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the category
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$event  =& $this->getTable('rg_events', '');

		// bind it to the table
		if (!$event->bind($data)) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}

		if (!$event->id) {
			$event->ordering = $event->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$event->check()) {
			$this->setError($event->getError());
			return false;
		}

		// Store it in the db
		if (!$event->store()) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_event	=& $event;
		
		return true;
	}
}
?>