<?php
/**
 * @version 1.0 $Id: galleryitem.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component state Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelState extends JModel
{
	/**
	 * Type data
	 *
	 * @var object
	 */
	var $_states = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int type identifier
	 */
	function setId($id)
	{
		// Set type id and wipe data
		$this->_id	    = $id;
		$this->_states	= null;
	}
	
	/**
	 * Overridden get method to get properties from the type
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadState()) {
			if(isset($this->_states->$property)) {
				return $this->_states->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get type data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getState()
	{
		if ($this->_loadState())
		{
		}
		else  $this->_initState();
		
		return $this->_states;
	}


	/**
	 * Method to load state data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadState()
	{
		// Lets load the type if it doesn't already exist
		if (empty($this->_states))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_states'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_states = $this->_db->loadObject();

			return (boolean) $this->_states;
		}
		return true;
	}

	/**
	 * Method to initialise the state data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initState()
	{
		// Lets load the state if it doesn't already exist
		if (empty($this->_states))
		{
			$state = new stdClass();
			$state->id					= 0;
			$state->parent_id			= 0;
			$state->name				= null;
			$state->alias				= null;
			$state->country				= 0;
			$state->code_1				= null;
			$state->code_2				= null;
			$state->published			= 1;
			$state->image				= null;
			$state->image_size			= 0;
			$state->imagewidth			= 0;
			$state->imageheight			= 0;
			$state->lat					= 0;
			$state->lon					= 0;
			$state->zoom				= 6;
			$state->maptype				= 'map';
			$state->mapheight			= 400;
			$state->meta_title			= null;
			$state->meta_description	= null;
			$state->meta_keywords		= null;
			$this->_states				= $state;
			return (boolean) $this->_states;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$state = & JTable::getInstance('rg_states', '');
			return $state->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the type
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$state = & JTable::getInstance('rg_states', '');
			return $state->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the type is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadState())
		{
			if ($uid) {
				return ($this->_states->checked_out && $this->_states->checked_out != $uid);
			} else {
				return $this->_states->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$state  =& $this->getTable('rg_states', '');
		
		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');

		// bind it to the table
		if (!$state->bind($data)) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$state->check()) {
			$this->setError($state->getError() );
			return false;
		}

		// Store it in the db
		if (!$state->store()) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_states	=& $state;

		//store tag relation
		$query = 'DELETE FROM #__rg_tags_item_relations WHERE state = '.$state->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__rg_tags_item_relations (`tid`, `state`) VALUES(' . $tag . ',' . $state->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		return true;
	}
	
	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	/**
	 * Method to fetch used tags when performing an edit action
	 * 
	 * @param int id
	 * @return array
	 * @since 1.0
	 */
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE state = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function addState($name, $country){
		
		$obj = new stdClass();
		$obj->name		= $name;
		$obj->country	= $country;
		$obj->published	= 1;
		
		$this->store($obj);
		
		return true;
	}
}
?>