<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelEvent extends JModel
{
	/**
	 * Event id
	 * @var int
	 */
	var $_id = null;
	
	/**
	 * Event items Data
	 * @var mixed
	 */
	var $_data = null;

	/**
	 * Childs
	 * @var mixed
	 */
	var $_childs = null;
	
	/**
	 * Event data
	 * @var object
	 */
	var $_events = null;

	/**
	 * Events total
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe, $rgconf;

		// Get the paramaters of the active menu item
		$params = & $mainframe->getParams('com_restaurantguide');
		
		$id			= JRequest::getInt('cid', 0);
		$this->setId((int)$id);

		//get the number of entries from session
		$limit		= $mainframe->getUserStateFromRequest('com_restaurantguide.events.limit', 'limit', $rgconf->maxeventlist, 'int');
		$limitstart		= JRequest::getInt('limitstart');

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'e.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}

	/**
	 * Method to set the category id
	 *
	 * @access	public
	 * @param	int	category ID number
	 */
	function setId($id)
	{
		// Set new category ID and wipe data
		$this->_id			= $id;
	}

	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return mixed
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}

		//check session if uservisit already recorded
		$session 	=& JFactory::getSession();
		$hitcheck = false;
		if ($session->has('hit', 'restaurantguide')) {
			$hitcheck 	= $session->get('hit', 0, 'restaurantguide');
			$hitcheck 	= in_array($this->_data->id, $hitcheck);
		}
		if (!$hitcheck) {
			//record hit
			$this->hit();

			$stamp = array();
			$stamp[] = $this->_data->id;
			$session->set('hit', $stamp, 'restaurantguide');
		}
			
		return $this->_data;
	}

	/**
	 * Total number of Events
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	/**
	 * Builds the query
	 *
	 * @access public
	 * @return string
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$query = 'SELECT e.*, i.title AS restaurantname,'
				. ' CASE WHEN CHAR_LENGTH(e.alias) THEN CONCAT_WS(\':\', e.id, e.alias) ELSE e.id END as slug,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as restaurantslug'
				. ' FROM #__rg_events AS e'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = e.resto'
				. ' WHERE e.published = 1'
				. ' AND e.parent_id = '. $this->_id
				. ' ORDER BY e.startdates DESC'
				;
				
		return $query;
	}

	/**
	 * Build the order clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemOrderBy()
	{
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_dir.', e.title';

		return $orderby;
	}

	/**
	 * Method to build the WHERE clause
	 *
	 * @access private
	 * @return array
	 */
	function _buildItemWhere( )
	{
		global $mainframe;

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		// Get the paramaters of the active menu item
		$params 	= & $mainframe->getParams('com_restaurantguide');

		// Second is to only select items the user has access to
		$states = '1, -4';
		if ($user->authorize('com_restaurantguide', 'state')) {
			$states .= ', 0 , -2, -3';
		}
		$where = ' AND e.published IN ('.$states.')';

		// Second is to only select items assigned to category the user has access to
		$where .= ' AND e.access <= '.$gid;

		/*
		* If we have a filter, and this is enabled... lets tack the AND clause
		* for the filter onto the WHERE clause of the item query.
		*/
		if ($params->get('filter'))
		{
			$filter 		= JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				$filter			= $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );

				$where .= ' AND LOWER( e.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
			}
		}
		return $where;
	}

	/**
	 * Method to build the Categories query
	 *
	 * @access private
	 * @return array
	 */
	function _buildChildsquery()
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$ordering	= 'ordering ASC';

		$query = 'SELECT *,'
				. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
				. ' FROM #__rg_events AS e'
				. ' WHERE e.published = 1'
				. ' AND e.parent_id = '. $this->_id
				. ' AND e.access <= '.$gid
				. ' ORDER BY e.startdates DESC'
				;
				
		return $query;
	}

	/**
	 * Method to get the childs of a category
	 *
	 * @access private
	 * @return array
	 */
	function getChilds()
	{
		$query = $this->_buildChildsquery();
		$this->_childs = $this->_db->loadObjectList();

		$k = 0;
		$count = count($this->_childs);
		for($i = 0; $i < $count; $i++)
		{
			$events =& $this->_childs[$i];

			$events->subevent = $this->_getsubs( $events->id );

			$k = 1 - $k;
		}

		return $this->_childs;
	}

	/**
	 * Method to build the Categories query
	 * todo: see above and merge
	 *
	 * @access private
	 * @return array
	 */
	function _getsubs($id)
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');

		$query = 'SELECT *,'
				. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
				. ' FROM #__rg_events'
				. ' WHERE published = 1'
				. ' AND parent_id = '. (int)$id
				. ' AND access <= '.$gid
				. ' ORDER BY startdates DESC'
				;

		$this->_db->setQuery($query);
		$this->_subs = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));

		return $this->_subs;
	}

	/**
	 * Method to load the Events
	 *
	 * @access public
	 * @return array
	 */
	function getEvent()
	{
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		//get travelnews
		$query = 'SELECT e.*, i.title AS restaurantname, ct.name AS cityname, s.name AS sname, co.name AS countryname,'
				. ' CASE WHEN CHAR_LENGTH(e.alias) THEN CONCAT_WS(\':\', e.id, e.alias) ELSE e.id END as slug,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as restaurantslug,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as catslug'
				. ' FROM #__rg_events AS e'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = e.resto'
				. ' LEFT JOIN #__rg_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__rg_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__rg_cities AS ct ON ct.id = e.city'
				. ' LEFT JOIN #__rg_states AS s ON s.id = e.statename'
				. ' LEFT JOIN #__rg_countries AS co ON co.id = e.country'
				. ' WHERE e.id = '.$this->_id
				. ' AND e.published = 1'
				. ' AND e.access <= '.$gid
				. ' ORDER BY e.startdates DESC'
				;

		$this->_db->setQuery($query);
		$this->_events = $this->_db->loadObject();
	
		//check whether category access level allows access
		//additional check
		if ($this->_events->access > $gid)
		{
			JError::raiseError(403, JText::_("ALERTNOTAUTH"));
			return false;
		}

		//check session if uservisit already recorded
		$session 	=& JFactory::getSession();
		$hitcheck = false;
		if ($session->has('hit', 'restaurantguide')) {
			$hitcheck 	= $session->get('hit', 0, 'restaurantguide');
			$hitcheck 	= in_array($this->_events->id, $hitcheck);
		}
		if (!$hitcheck) {
			//record hit
			$this->hit();

			$stamp = array();
			$stamp[] = $this->_events->id;
			$session->set('hit', $stamp, 'restaurantguide');
		}
		
		return $this->_events;
	}

	function hit()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('rg_events', '');
			$item->hit($this->_id);
			return true;
		}
		return false;
	}
	
	function getPreviousEvent($eventid, $ordering){
		
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$db = & JFactory::getDBO ();

		//get travelnews
		$query = 'SELECT e.*,'
				. ' CASE WHEN CHAR_LENGTH(e.alias) THEN CONCAT_WS(\':\', e.id, e.alias) ELSE e.id END as slug'
				. ' FROM #__rg_events AS e'
				. ' WHERE e.id != '.$eventid
				. ' AND e.ordering > '.$ordering
				. ' AND e.published = 1'
				. ' AND e.parent_id > 0'
				. ' AND e.access <= '.$gid
				. ' ORDER BY e.ordering ASC'
				;

		$db->setQuery($query,0,1);
		$row = $db->loadObject();

		return $row;
	}
	
	function getNextEvent($eventid, $ordering){

		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$db = & JFactory::getDBO ();

		//get travelnews
		$query = 'SELECT e.*,'
				. ' CASE WHEN CHAR_LENGTH(e.alias) THEN CONCAT_WS(\':\', e.id, e.alias) ELSE e.id END as slug'
				. ' FROM #__rg_events AS e'
				. ' WHERE e.id != '.$eventid
				. ' AND e.ordering < '.$ordering
				. ' AND e.published = 1'
				. ' AND e.parent_id > 0'
				. ' AND e.access <= '.$gid
				. ' ORDER BY e.ordering DESC'
				;

		$db->setQuery($query,0,1);
		$row = $db->loadObject();

		return $row;
	}
	
	function getParentTitle($id)
	{
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		//get categories
		$query = 'SELECT e.title'
				. ' FROM #__rg_events AS e'
				. ' WHERE e.id = '.$this->_id
				. ' AND e.published = 1'
				. ' AND e.access <= '.$gid
				;

		$this->_db->setQuery($query);
		$parent = $this->_db->loadObject();
		return $parent;
	}
	
	function getExistSub($id)
	{
		$query = 'SELECT COUNT( id )'
				. ' FROM #__rg_events'
				. ' WHERE published = 1'
				. ' AND parent_id = '. (int)$id
				;
		$this->_db->setQuery( $query );
		$count = $this->_db->loadResult();
			
		if ($count > 0) {
			return true;
		}
		
		return false;
	}
}
?>