<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with HOTELGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelSearch extends JModel
{
	var $_id = null;
	var $_data = null;
	var $_total = null;
	
	/**
	 * Constructor
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe, $rgconf;

		// Get the paramaters of the active menu item
		$params = & $mainframe->getParams('com_restaurantguide');
		//get the number of entries from session
		$limit		= $mainframe->getUserStateFromRequest('com_restaurantguide.search.limit', 'limit', $params->def('limit', 0), 'int');
		$limitstart		= JRequest::getInt('limitstart');

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}

	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return mixed
	 */
	function getData()
	{
		global $mainframe, $option, $rgconf;
			
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$this->_data = $this->_getList( $this->_buildQuery(), $this->getState('limitstart'), $this->getState('limit') );
			
			$count = count($this->_data);

			$i = 0;
			foreach($this->_data as $data) :
				$temp = $data->cuisines;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}

				$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS cuisines'
					. ' FROM #__rg_cuisines'
					. $where
					;
					
				$this->_db->setQuery($query);
				$this->_data[$i]->cuisinelist = $this->_db->loadObject();
				
				$temp = $data->tags;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}
				$query = 'SELECT DISTINCT name,'
						. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
						. ' FROM #__rg_tags'
						. $where
						. ' ORDER BY name ASC'
						;
				
				$this->_db->setQuery($query);
				$this->_data[$i]->taglist = $this->_db->loadObjectList();
				
				$i ++;
			endforeach;
		}

		return $this->_data;
	}

	/**
	 * Total nr of Categories
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();

		$query = 'SELECT DISTINCT i.id, i.title, i.alias, i.mainimage, i.address, i.city, i.country, i.featured, i.hits,'
				. ' i.introduction, i.facilities, i.cuisines, i.lat, i.lon, i.maptype, i.mainimage, i.zoom, i.imagewidth, i.imageheight, '
				. ' i.rate,  i.rate_sum, w.name AS cityname, t.name AS restauranttype, (i.rate_sum / i.rate ) AS votes, '
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as categoryslug,'
					. ' (SELECT GROUP_CONCAT('
					. ' tag.tid ORDER BY tag.tid ASC SEPARATOR \', \')'
					. ' FROM #__rg_tags_item_relations AS tag'
					. ' WHERE tag.itemid IN(i.id)'
					. ' )' 
					. ' AS tags'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__rg_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__rg_restauranttypes AS t ON t.id = i.tid'
				. ' LEFT JOIN #__rg_cities AS w on w.id = i.city'
				. ' LEFT JOIN #__users AS u ON u.id = i.created_by'
				. $where
				. $orderby
				;

		return $query;
	}
	
	function _buildContentOrderBy()
	{
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		if ($filter_order == 'title')
			$orderby 	= ' ORDER BY i.title '.$filter_order_dir;
		else if ($filter_order == 'hits')
			$orderby 	= ' ORDER BY i.hits '.$filter_order_dir.', i.title ASC';
		else if ($filter_order == 'votes')
			$orderby 	= ' ORDER BY votes '.$filter_order_dir.', i.title ASC';
		else if ($filter_order == 'type')
			$orderby 	= ' ORDER BY restauranttype '.$filter_order_dir.', i.title ASC';
		else
			$orderby 	= ' ORDER BY i.title ASC';

		return $orderby;
	}
	
	function _buildContentWhere()
	{
		global $mainframe, $option;

		$search 			= $mainframe->getUserStateFromRequest( $option.'.search.search', 'search', '', 'string' );
		$search 			= $this->_db->getEscaped( trim(JString::strtolower( $search ) ) );
		
		$filter_country		= JRequest::getInt('filter_country', 0);
		$filter_states		= JRequest::getInt('filter_states', 0);
		$filter_city		= JRequest::getInt('filter_city', 0);
		$cuisine_search		= JRequest::getVar('cuisine_search', array(), '', 'array');	
		$cuisine_search		= implode(', ', $cuisine_search);
		
		$atmo_search        = JRequest::getVar('atmo_search', array(), '', 'array');	
		$atmo_search		= implode(', ', $atmo_search);			
		
		$where = array();
		
		$where[] = ' i.state = 1';

		if ($filter_country) {
			$where[] = ' i.country = '.$filter_country;
		}
		
		if ($filter_states) {
			$where[] = ' i.statename = '.$filter_states ;
		}
		
		if ($filter_city) {
			$where[] = ' i.city = '.$filter_city ;
		}
		
		if ($cuisine_search) {
			$where[] = ' i.cuisines IN ('.$cuisine_search.')';
		}
		
		if ($atmo_search) {
			$where[] = ' i.atmos IN ('.$atmo_search.')';
		}

		
		if ($search) {
			$where[] = ' LOWER(i.title) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $search, true ).'%', false );
		}

		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );
		
		return $where;
	}

	/**
	 * Method to build the WHERE clause
	 *
	 * @access private
	 * @return array
	 */
	function _buildItemWhere( )
	{
		global $mainframe;

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		// Get the paramaters of the active menu item
		$params 	= & $mainframe->getParams('com_restaurantguide');

		// First thing we need to do is to select only the requested items
//		$where = ' WHERE rel.catid = '.$this->_id;

		// Second is to only select items the user has access to
		$states = '1, -4';
		if ($user->authorize('com_restaurantguide', 'state')) {
			$states .= ', 0 , -2, -3';
		}
		$where = ' AND i.state IN ('.$states.')';

		// Second is to only select items assigned to category the user has access to
		$where .= ' AND c.access <= '.$gid;

		/*
		* If we have a filter, and this is enabled... lets tack the AND clause
		* for the filter onto the WHERE clause of the item query.
		*/
		if ($params->get('filter'))
		{
			$filter = JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				$filter = $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );

				$where .= ' AND LOWER( i.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
			}
		}
		return $where;
	}

	function getMapData()
	{
		global $mainframe, $option;

		$filter_country 	= $mainframe->getUserStateFromRequest($option.'.search.filter_country', 'filter_country', 0, 'int');
		$filter_states	 	= $mainframe->getUserStateFromRequest($option.'.search.filter_states', 'filter_states', 0, 'int');
		$filter_city	 	= $mainframe->getUserStateFromRequest($option.'.search.filter_city', 'filter_city', 0, 'int');
		$filter_cuisines	= $mainframe->getUserStateFromRequest($option.'.search.filter_cuisines', 'filter_cuisines', '*', 'word');
		
		$where = ' WHERE i.state = 1';
		$where .= ' AND i.lon != 0';

		if ($filter_country) {
			$where .= ' AND i.country = "'.$filter_country.'"' ;
		}
		if ($filter_states) {
			$where .= ' AND i.statename = '.$filter_states ;
		}
		if ($filter_city) {
			$where .= ' AND i.city = '.$filter_city ;
		}
				
		$query = 'SELECT DISTINCT i.id, i.title, i.lat, i.lon, i.maptype, i.mainimage, i.zoom, i.imagewidth, i.imageheight,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__rg_restaurantitems AS i'
				. $where
				. ' ORDER BY i.title ASC'
				;
		
		$this->_db->setQuery($query);
		$result = $this->_db->loadObjectList();

		return $result;
	}
	
	function getCountries()
	{			
		$query = 'SELECT c.id AS value, c.name AS text'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_countries AS c ON c.id = i.country'
				. ' WHERE i.state = 1'
				. ' GROUP BY i.country'
				;
	
		$this->_db->setQuery( $query );
		$country = $this->_db->loadObjectList();

		return $country;
	}
	
	function getStates()
	{
		global $mainframe, $option;

		$filter_country 	= $mainframe->getUserStateFromRequest($option.'.search.filter_country', 'filter_country', 0, 'int');
		$query = 'SELECT s.id AS value, s.name AS text'
				. ' FROM #__rg_states AS s'
				. ' WHERE s.published = 1'
				. ' AND s.country = '.$filter_country
				. ' ORDER BY s.name ASC'
				;

		$this->_db->setQuery( $query );
		$states = $this->_db->loadObjectList();

		return $states;
	}
	
	function getCities()
	{
		global $mainframe, $option;

		$filter_country 	= $mainframe->getUserStateFromRequest($option.'.search.filter_country', 'filter_country', 0, 'int');
		$query = 'SELECT t.id AS value, t.name AS text'
				. ' FROM #__rg_cities AS t'
				. ' WHERE t.published = 1'
				. ' AND t.country = '.$filter_country
				. ' AND t.parent_id = 0' 
				. ' ORDER BY t.name ASC'
				;
	
		$this->_db->setQuery( $query );
		$city = $this->_db->loadObjectList();

		return $city;
	}
	
	function getDestinations()
	{			
		$query = 'SELECT c.*,'
				. ' CASE WHEN CHAR_LENGTH( c.alias ) THEN CONCAT_WS( \':\', c.id, c.alias ) ELSE c.id END AS slug,'
					. ' ('
					. ' SELECT COUNT( DISTINCT i.id )'
					. ' FROM #__rg_restaurantitems AS i'
					. ' LEFT JOIN #__rg_cities AS cc ON cc.id = i.city'
					. ' WHERE i.city = c.id'
					. ')' 
					. ' AS assignedrestaurants'
				. ' FROM #__rg_cities AS c'
				. ' WHERE c.published = 1'
				. ' AND c.parent_id = 0' 
				. ' AND c.destination > 0'
				. ' ORDER BY c.destination ASC'
				. ' LIMIT 5'
				;
				
		$this->_db->setQuery( $query );
		$results = $this->_db->loadObjectList();

		for($i=0;$i < count($results); $i++){
			$city_id = $results[$i]->id;
			$query = 'SELECT i.title,'
					. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
					. ' CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(\':\', cc.id, cc.alias) ELSE cc.id END as categoryslug'
					. ' FROM #__rg_restaurantitems AS i'
					. ' LEFT JOIN #__rg_cats_item_relations AS rel ON rel.itemid = i.id'
					. ' LEFT JOIN #__rg_categories AS cc ON cc.id = rel.catid'
					. ' LEFT JOIN #__rg_cities AS c on c.id = i.city'
					. ' WHERE c.published = 1'
					. ' AND c.parent_id = 0' 
					. ' AND c.destination > 0'
					. ' AND i.featured > 0'
					. ' AND c.id = '.$city_id
					. ' ORDER BY i.title ASC'
					;
					
			$this->_db->setQuery( $query );
			$results[$i]->restaurants = $this->_db->loadObjectList();
		}
	
		return $results;
	}
}
?>