<?php
/**
 * @version 1.0 beta $Id: tags.php 
 * @package Joomla
 * @subpackage Restaurant Guide
 * @copyright (C) 2009 - 2010 Oh-Taek Im - www.photoindochina.com
 * @license GNU/GPL v2
 *
 * Restaurant Guide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * Restaurant Guide Component Model
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since		1.0
 */
class restaurantguideModelTags extends JModel
{
	/**
	 * Data
	 *
	 * @var mixed
	 */
	var $_data = null;
	
	/**
	 * Tag
	 *
	 * @var mixed
	 */
	var $_tag = null;
	
	/**
	 * Items total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe;

		// Get the paramaters of the active menu item
		$params = & $mainframe->getParams('com_restaurantguide');

		//get the number of events from database
		$limit			= JRequest::getInt('limit');//JRequest::getInt('limit', $params->get('limit'));
		$limitstart		= JRequest::getInt('limitstart');
		$id				= JRequest::getInt('id', 0);
		
		$this->setId((int)$id);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
		
		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}
	
	/**
	 * Method to set the tag id
	 *
	 * @access	public
	 * @param	int	tag ID number
	 */
	function setId($id)
	{
		// Set new category ID and wipe data
		$this->_id			= $id;
		$this->_data		= null;
	}

	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return object
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{		
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
			
			$count = count($this->_data);

			$i = 0;
			foreach($this->_data as $data) :
				$temp = $data->cuisines;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}

				$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS cuisines'
						. ' FROM #__rg_cuisines'
						. $where
						;
						
				$this->_db->setQuery($query);
				$this->_data[$i]->cuisinelist = $this->_db->loadObject();
				
				$query = 'SELECT DISTINCT name,'
						. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
						. ' FROM #__rg_tags'
						. ' WHERE  id IN ('.$data->tags.')'
						;
				
				$this->_db->setQuery($query);
				$this->_data[$i]->taglist = $this->_db->loadObjectList();
				
				$i ++;
			endforeach;
		}
		
		return $this->_data;
	}
	
	/**
	 * Total nr of Items
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}
	
	/**
	 * Method to build the query
	 *
	 * @access public
	 * @return string
	 */
	function _buildQuery()
	{   	
        // Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildItemWhere();
		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT i.*, c.id AS catid, w.name AS cityname, type.name AS restauranttype,'
					. ' i.rate, i.rate_sum, (i.rate_sum / i.rate ) AS votes,'
					. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
					. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as categoryslug,'
						. ' (SELECT GROUP_CONCAT('
						. ' tag.tid ORDER BY tag.tid ASC SEPARATOR \', \')'
						. ' FROM #__rg_tags_item_relations AS tag'
						. ' WHERE tag.itemid IN(i.id)'
						. ' )' 
						. ' AS tags'
					. ' FROM #__rg_restaurantitems AS i'
					. ' INNER JOIN #__rg_tags_item_relations AS t ON t.itemid = i.id'
					. ' LEFT JOIN #__rg_cats_item_relations AS rel ON rel.itemid = i.id'
					. ' LEFT JOIN #__rg_categories AS c ON c.id = rel.catid'
					. ' LEFT JOIN #__rg_restauranttypes AS type ON type.id = i.tid'
					. ' LEFT JOIN #__rg_cities AS w on w.id = i.city'
					. $where
					. ' GROUP BY i.id'
					. $orderby
					;

		return $query;
	}

	/**
	 * Build the order clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemOrderBy()
	{	
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_dir.', i.title';

		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemWhere( )
	{
		$where = ' WHERE i.state = 1';
		$where .= ' AND t.tid = '.$this->_id;

		return $where;
	}
	
	/**
	 * Method to load the Tag data
	 *
	 * @access public
	 * @return object
	 */
	function getTag()
	{
		//get categories
		$query = 'SELECT t.name, t.id,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__rg_tags AS t'
				. ' WHERE t.id = '.$this->_id
				. ' AND t.published = 1'
				;

		$this->_db->setQuery($query);
        $this->_tag = $this->_db->loadObject();
        
		return $this->_tag;
	}
	
	function getAlltags($userid, $limit)
	{
		$user =& JFactory::getUser();
		$result = array();
		$query = 'SELECT t.*'
				. ' FROM #__rg_tags AS t'
				. ' WHERE t.published = 1'
				. ' GROUP BY t.id'
				. ' ORDER BY t.name'
				;
		$this->_db->setQuery($query, 0, $limit);
		$result = $this->_db->loadResultArray();

		return $result;
	}
	
	function getCountTags($min)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__rg_tags AS t'
				. ' LEFT JOIN #__rg_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= '. $min
				. ' ORDER BY t.name'
				;
				
		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getLimitTags($number)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__rg_tags AS t'
				. ' LEFT JOIN #__rg_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= 1'
				. ' ORDER BY t.name'
				;
				
		$this->_db->setQuery($query,0,$number);
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getTagCloud($limit, $minsize, $maxsize)
	{
		$where  = ' WHERE i.state = 1';
		$where .= ' AND tag.published = 1';
//		$where .= ' AND tag.userid = '.$userid;
		
		//Count Tags
		$result = array();
		
		$query = 'SELECT COUNT( t.tid ) AS no'
				. ' FROM #__rg_tags_item_relations AS t'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = t.itemid'
				. ' LEFT JOIN #__rg_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__rg_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__rg_tags as tag ON tag.id = t.tid'
				. $where
				. ' GROUP BY t.tid'
				. ' ORDER BY no DESC'
				;

		$this->_db->setQuery($query, 0, $limit);
		$result = $this->_db->loadResultArray();
		
		//Do we have any tags?
		if (!$result) {
			return $result;
		}
		
		$max = (int)$result[0];
		$min = (int)$result[sizeof($result)-1];
		
		$query = 'SELECT tag.id, tag.name, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(tag.alias) THEN CONCAT_WS(\':\', tag.id, tag.alias) ELSE tag.id END as slug'
				. ' FROM #__rg_tags AS tag'
				. ' LEFT JOIN #__rg_tags_item_relations AS rel ON rel.tid = tag.id'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = rel.itemid'
				. $where
				. ' GROUP BY tag.id'
				. ' HAVING no >= '. $min
				. ' ORDER BY tag.name'
				;
		
		$this->_db->setQuery($query, 0, $limit);
		$rows = $this->_db->loadObjectList();
		
		$i		= 0;
		$lists	= array();
		foreach ( $rows as $row )
		{	
			$lists[$i]->size 			= $this->sizer($min, $max, $row->no, $minsize, $maxsize);
			$lists[$i]->name 			= $row->name;
			$lists[$i]->screenreader	= JText::sprintf('NR_ITEMS_TAGGED', $row->no);
			$lists[$i]->link 			= JRoute::_(restaurantguideHelperRoute::getTagRoute($row->slug));
			$i++;
		}

		return $lists;
	}
	
	function sizer($min, $max, $no, $minsize, $maxsize)
	{		
		$spread = $max - $min;
		if (0 == $spread) {
	   		$spread = 1;
		}

		$step = ($maxsize - $minsize) / $spread;

    	$size = $minsize + (($no - $min) * $step);
		$size = ceil($size);
		
		if ($size > $maxsize)
			$size = $maxsize;
			
		return $size;
	}
	
	function getAvatar($userid) {

		$query = 'SELECT u.*, g.name AS groupname'
				. ' FROM #__g_user AS u'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. ' WHERE u.userID = '.$userid
				;
		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();
			
		return $row;
	}
	
	function getMainCategory()
	{
		//get categories
		$query = 'SELECT c.*,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
				. ' FROM #__rg_categories AS c'
				. ' WHERE c.parent_id = 0'
				. ' AND c.published = 1'
				;

		$this->_db->setQuery($query);
		$maincategory = $this->_db->loadObject();

		return $maincategory;
	}

}
?>